/*
** Module   : RemoteInvocationResult.java
** Abstract : Container for the result of a remote server procedure call. 
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20131220 Created initial version.
*/

package com.goldencode.p2j.main;

/**
 * This class acts as a container for the various data which is returned by or updated during 
 * remote server calls.  This includes the function/procedure return value, updated 
 * OUTPUT/INPUT-OUTPUT parameters or the returned error.
 */
public class RemoteInvocationResult
{
   /** The updated parameters, after the remote call. */
   protected Object[] arguments = new Object[0];
   
   /** The function/procedure call result. */
   protected Object result;

   /** The resolved parameter modes for this call. */
   protected String modes;

   /** The error thrown during the remote call or connection request. */
   protected Throwable error;

   /**
    * Get the returned result, after a function or procedure invocation.
    * 
    * @return   The {@link #result} field.
    */
   public Object getResult()
   {
      return result;
   }

   /**
    * Set the result of this remote call.
    * 
    * @param    result
    *           The result of this remote invocation.
    */
   public void setResult(Object result)
   {
      this.result = result;
   }

   /**
    * Get any error thrown by the last remote request.
    * 
    * @return   The {@link #error} field.
    */
   public Throwable getError()
   {
      return this.error;
   }

   /**
    * Set the error thrown by the current remote request.
    * 
    * @param    error
    *           The caught error.
    */
   public void setError(Throwable error)
   {
      this.error = error;
   }

   /**
    * Getter for the {@link #arguments} field.
    * 
    * @return   See above.
    */
   public Object[] getArguments()
   {
      return arguments;
   }

   /**
    * Setter for the {@link #arguments} field.
    * 
    * @param    arguments
    *           The updated arguments, to sent back to the caller.
    */
   public void setArguments(Object[] arguments)
   {
      this.arguments = arguments;
   }

   /**
    * Get the resolved parameter modes for this call.
    *  
    * @return   See above.
    */
   public String getModes()
   {
      return modes;
   }
   
   /**
    * Set the resolved parameter modes for this call.
    * 
    * @param    modes
    *           The resolved parameter modes.
    */
   public void setModes(String modes)
   {
      this.modes = modes;
   }
   
   /**
    * Check if the RETURN-VALUE will be set.
    * 
    * @return   By default, returns <code>false</code>.
    */
   public boolean setReturnValue()
   {
      return false;
   }
}
